@@ -6,11 +6,11 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-use crate::situation::Transition;
 use crate::situation::WhatNow;
 use crate::situation::flush;
 use crate::situation::if_needed;
 use crate::situation::pop;
+use crate::situation::push;
 use crate::situation::COLOR_HERE;
 use crate::situation::COLOR_KWD;
 use crate::situation::COLOR_SQ;
@@ -31,7 +31,8 @@ use crate::sitfor::SitFor;
 use crate::sitcmd::SitNormal;
 use crate::sitcmd::SitCmd;
 use crate::sitcomment::SitComment;
-use crate::sitextent::SitExtent;
+use crate::sitextent::push_extent;
+use crate::sitextent::push_replaceable;
 use crate::sitmagic::push_magic;
 use crate::sitrvalue::SitRvalue;
 use crate::sitstrdq::SitStrDq;
@@ -55,10 +56,7 @@ pub fn keyword_or_command(
 		return flush(i);
 	}
 	if found == Tri::Yes {
-		return WhatNow{
-			tri: Transition::Push(Box::new(SitRvalue{end_trigger})),
-			pre: i + len, len: 0, alt: None
-		};
+		return push((i + len, 0, None), Box::new(SitRvalue { end_trigger }));
 	}
 	let len = predlen(is_word, &horizon[i..]);
 	let len = if len != 0 { len } else { prefixlen(&horizon[i..], b"((") };
@@ -67,22 +65,18 @@ pub fn keyword_or_command(
 	}
 	let word = &horizon[i..i+len];
 	match word {
-		b"(" => WhatNow{
-			tri: Transition::Push(Box::new(SitNormal{
-				end_trigger: u16::from(b')'), end_replace: None
-			})), pre: i, len: 1, alt: None
-		},
+		b"(" => push(
+			(i, 1, None),
+			Box::new(SitNormal {
+				end_trigger: u16::from(b')'),
+				end_replace: None,
+			}),
+		),
 		b"((" => push_magic(i, 1, b')'),
 		b"[[" => push_magic(i, 1, b']'),
-		b"case" => WhatNow{
-			tri: Transition::Push(Box::new(SitCase{})),
-			pre: i, len, alt: None
-		},
+		b"case" => push((i, len, None), Box::new(SitCase {})),
 		b"for" |
-		b"select" => WhatNow{
-			tri: Transition::Push(Box::new(SitFor{})),
-			pre: i, len, alt: None
-		},
+		b"select" => push((i, len, None), Box::new(SitFor {})),
 		b"!" |
 		b"declare" |
 		b"do" |
@@ -99,19 +93,12 @@ pub fn keyword_or_command(
 		b"until" |
 		b"while" |
 		b"{" |
-		b"}" => WhatNow{
-			tri: Transition::Push(Box::new(SitExtent{len: 0, color: COLOR_KWD})),
-			pre: i, len, alt: None,
-		},
+		b"}" => push_extent(COLOR_KWD, i, len),
 		b"[" |
-		b"test" if predlen(|x| x == b' ', &horizon[i + len ..]) == 1 => WhatNow{
-			tri: Transition::Push(Box::new(SitTest{end_trigger})),
-			pre: i, len: len + 1, alt: None,
-		},
-		_ => WhatNow{
-			tri: Transition::Push(Box::new(SitCmd{end_trigger})),
-			pre: i, len: 0, alt: None
+		b"test" if predlen(|x| x == b' ', &horizon[i + len ..]) == 1 => {
+			push((i, len + 1, None), Box::new(SitTest { end_trigger }))
 		},
+		_ => push((i, 0, None), Box::new(SitCmd { end_trigger })),
 	}
 }
 
@@ -163,13 +150,12 @@ pub fn common_token(
 	match common_str_cmd(horizon, i, is_horizon_lengthenable, QuotingCtx::Need) {
 		CommonStrCmdResult::None => None,
 		CommonStrCmdResult::Some(x) => Some(x),
-		CommonStrCmdResult::OnlyWithQuotes(_) => {
-			Some(WhatNow{
-				tri: Transition::Push(Box::new(SitStrPhantom{
-					cmd_end_trigger: end_trigger,
-				})), pre: i, len: 0, alt: Some(b"\"")
-			})
-		}
+		CommonStrCmdResult::OnlyWithQuotes(_) => Some(push(
+			(i, 0, Some(b"\"")),
+			Box::new(SitStrPhantom {
+				cmd_end_trigger: end_trigger,
+			}),
+		)),
 	}
 }
 
@@ -210,15 +196,18 @@ pub fn common_token_quoting_unneeded(
 		CommonStrCmdResult::None => None,
 		CommonStrCmdResult::Some(x) => Some(x),
 		CommonStrCmdResult::OnlyWithQuotes(x) => {
-			if let Some(replacement) = x.alt {
-				if replacement.len() >= x.len {
+			let (_, len, alt) = x.transform;
+			if let Some(replacement) = alt {
+				if replacement.len() >= len {
 					#[allow(clippy::collapsible_if)] // Could be expanded.
 					if horizon[i] == b'`' {
-						return Some(WhatNow{
-							tri: Transition::Push(Box::new(SitNormal{
-								end_trigger: u16::from(b'`'), end_replace: None
-							})), pre: i, len: 1, alt: None
-						});
+						return Some(push(
+							(i, 1, None),
+							Box::new(SitNormal {
+								end_trigger: u16::from(b'`'),
+								end_replace: None,
+							}),
+						));
 					}
 				}
 			}
@@ -259,18 +248,16 @@ fn find_usual_suspects(
 		return Some(pop(i, 0, None));
 	}
 	if a == b'\'' {
-		return Some(WhatNow{
-			tri: Transition::Push(Box::new(SitUntilByte{
-				until: b'\'', color: COLOR_SQ,
-			})),
-			pre: i, len: 1, alt: None
-		});
+		return Some(push(
+			(i, 1, None),
+			Box::new(SitUntilByte {
+				until: b'\'',
+				color: COLOR_SQ,
+			}),
+		));
 	}
 	if a == b'\"' {
-		return Some(WhatNow{
-			tri: Transition::Push(Box::new(SitStrDq::new())),
-			pre: i, len: 1, alt: None
-		});
+		return Some(push((i, 1, None), Box::new(SitStrDq::new())));
 	}
 	if a == b'$' {
 		if i+1 >= horizon.len() {
@@ -281,17 +268,10 @@ fn find_usual_suspects(
 		}
 		let b = horizon[i+1];
 		if b == b'\'' {
-			return Some(WhatNow{
-				tri: Transition::Push(Box::new(SitStrSqEsc{})),
-				pre: i, len: 2, alt: None
-			});
+			return Some(push((i, 2, None), Box::new(SitStrSqEsc {})));
 		} else if b == b'*' {
 			// $* → "$@" but not "$*" → "$@"
-			let ext = Box::new(SitExtent{len: 0, color: COLOR_VAR});
-			return Some(WhatNow{
-				tri: Transition::Push(ext),
-				pre: i, len: 2, alt: if_needed(quoting_needed, b"\"$@\"")
-			});
+			return Some(push_replaceable(COLOR_VAR, i, 2, if_needed(quoting_needed, b"\"$@\"")));
 		}
 	}
 	let (ate, delimiter) = find_heredoc(&horizon[i ..]);
@@ -300,12 +280,13 @@ fn find_usual_suspects(
 			return Some(flush(i));
 		}
 	} else if !delimiter.is_empty() {
-		return Some(WhatNow{
-			tri: Transition::Push(Box::new(
-				SitVec{terminator: delimiter, color: COLOR_HERE}
-			)),
-			pre: i, len: ate, alt: None
-		});
+		return Some(push(
+			(i, ate, None),
+			Box::new(SitVec {
+				terminator: delimiter,
+				color: COLOR_HERE,
+			}),
+		));
 	} else if ate > 0 {
 		return Some(flush(i + ate));
 	}
@@ -313,10 +294,7 @@ fn find_usual_suspects(
 }
 
 fn push_comment(pre: usize) -> WhatNow {
-	WhatNow{
-		tri: Transition::Push(Box::new(SitComment{})),
-		pre, len: 1, alt: None
-	}
+	push((pre, 1, None), Box::new(SitComment {}))
 }
 
 #[derive(PartialEq)]
@@ -430,6 +408,7 @@ fn test_find_lvalue() {
 	assert!(find_lvalue(b"[]") == (Tri::No, 0));
 	assert!(find_lvalue(b"esa") == (Tri::Maybe, 3));
 	assert!(find_lvalue(b"esa+") == (Tri::Maybe, 4));
+	assert!(find_lvalue(b"esa+  ") == (Tri::No, 5));
 	assert!(find_lvalue(b"esa[]") == (Tri::Maybe, 5));
 	assert!(find_lvalue(b"esa[]+") == (Tri::Maybe, 6));
 	assert!(find_lvalue(b"esa ") == (Tri::No, 4));
