@@ -7,8 +7,10 @@
  */
 
 use crate::situation::Transition;
+use crate::situation::UnsupportedSyntax;
 use crate::situation::WhatNow;
 use crate::situation::flush;
+use crate::situation::push;
 use crate::situation::if_needed;
 use crate::situation::COLOR_ESC;
 use crate::situation::COLOR_VAR;
@@ -18,10 +20,10 @@ use crate::microparsers::is_identifierhead;
 use crate::microparsers::is_identifiertail;
 use crate::microparsers::identifierlen;
 
-use crate::syntaxerror::UnsupportedSyntax;
 
 use crate::sitcmd::SitNormal;
-use crate::sitextent::SitExtent;
+use crate::sitextent::push_extent;
+use crate::sitextent::push_replaceable;
 use crate::sitmagic::push_magic;
 use crate::sitvarbrace::SitVarBrace;
 use crate::sitvarident::SitVarIdent;
@@ -59,18 +61,16 @@ pub fn common_str_cmd(
 				return found_pwd;
 			}
 		}
-		let cmd = Box::new(SitNormal{
-			end_trigger: u16::from(b'`'), end_replace: Some(b")"),
-		});
-		return CommonStrCmdResult::OnlyWithQuotes(WhatNow{
-			tri: Transition::Push(cmd), pre: i, len: 1, alt: Some(b"$(")
-		});
+		return CommonStrCmdResult::OnlyWithQuotes(push(
+			(i, 1, Some(b"$(")),
+			Box::new(SitNormal {
+				end_trigger: u16::from(b'`'),
+				end_replace: Some(b")"),
+			}),
+		));
 	}
 	if horizon[i] == b'\\' {
-		let esc = Box::new(SitExtent{len: 1, color: COLOR_ESC});
-		return CommonStrCmdResult::Some(WhatNow{
-			tri: Transition::Push(esc), pre: i, len: 1, alt: None
-		});
+		return CommonStrCmdResult::Some(push_extent(COLOR_ESC, i, 2));
 	}
 	if horizon[i] != b'$' {
 		return CommonStrCmdResult::None;
@@ -96,28 +96,21 @@ pub fn common_str_cmd(
 		} else if horizon[i+2] == b'(' {
 			return CommonStrCmdResult::Some(push_magic(i, 2, b')'));
 		}
-		let sit = Box::new(SitNormal{
-			end_trigger: u16::from(b')'), end_replace: None,
-		});
-		return CommonStrCmdResult::OnlyWithQuotes(WhatNow{
-			tri: Transition::Push(sit),
-			pre: i, len: 2, alt: None
-		});
+		return CommonStrCmdResult::OnlyWithQuotes(push(
+			(i, 2, None),
+			Box::new(SitNormal {
+				end_trigger: u16::from(b')'),
+				end_replace: None,
+			}),
+		));
 	} else if is_variable_of_numeric_content(c) {
-		let ext = Box::new(SitExtent{len: 2, color: COLOR_VAR});
-		return CommonStrCmdResult::Some(WhatNow{
-			tri: Transition::Push(ext),
-			pre: i, len: 0, alt: None
-		});
+		return CommonStrCmdResult::Some(push_extent(COLOR_VAR, i, 2));
 	} else if c == b'@' || c == b'*' || c == b'-' || is_decimal(c) {
-		if predlen(is_decimal, &horizon[i+1 ..]) > 1 {
-			return bail_doubledigit(horizon, i+2);
+		let digitlen = predlen(is_decimal, &horizon[i+1 ..]);
+		if digitlen > 1 {
+			return bail_doubledigit(i, 1 + digitlen);
 		}
-		let ext = Box::new(SitExtent{len: 2, color: COLOR_VAR});
-		return CommonStrCmdResult::OnlyWithQuotes(WhatNow{
-			tri: Transition::Push(ext),
-			pre: i, len: 0, alt: None
-		});
+		return CommonStrCmdResult::OnlyWithQuotes(push_extent(COLOR_VAR, i, 2));
 	} else if is_identifierhead(c) {
 		let tailhazard;
 		if need_quotes {
@@ -134,11 +127,12 @@ pub fn common_str_cmd(
 		} else {
 			tailhazard = false;
 		}
-		return CommonStrCmdResult::OnlyWithQuotes(WhatNow{
-			tri: Transition::Push(Box::new(SitVarIdent{
-				end_insert: if_needed(tailhazard, b"}")
-			})), pre: i, len: 1, alt: if_needed(tailhazard, b"${")
-		});
+		return CommonStrCmdResult::OnlyWithQuotes(push(
+			(i, 1, if_needed(tailhazard, b"${")),
+			Box::new(SitVarIdent {
+				end_insert: if_needed(tailhazard, b"}"),
+			}),
+		));
 	} else if c == b'{' {
 		let cand: &[u8] = &horizon[i+2 ..];
 		let (idlen, pos_hazard) = pos_tailhazard(cand, b'}');
@@ -154,10 +148,10 @@ pub fn common_str_cmd(
 			let is_interpolation = is_interpolation || pos_hazard - idlen == 1;
 			rm_braces = need_quotes || !is_interpolation;
 		}
-		let wn = WhatNow{
-			tri: Transition::Push(Box::new(SitVarBrace::new(rm_braces, need_quotes))),
-			pre: i, len: 2, alt: if_needed(rm_braces, b"$"),
-		};
+		let wn = push(
+			(i, 2, if_needed(rm_braces, b"$")),
+			Box::new(SitVarBrace::new(rm_braces, need_quotes)),
+		);
 		return if is_number {
 			CommonStrCmdResult::Some(wn)
 		} else {
@@ -187,12 +181,8 @@ fn find_pwd(
 		} else {
 			b"$PWD"
 		};
-		let sit = Box::new(SitExtent{len: 0, color: COLOR_VAR});
-		return CommonStrCmdResult::OnlyWithQuotes(WhatNow{
-			tri: Transition::Push(sit),
-			pre: i, len: candidate_offset + idlen + 1,
-			alt: Some(replacement)
-		});
+		let what = push_replaceable(COLOR_VAR, i, candidate_offset + idlen + 1, Some(replacement));
+		return CommonStrCmdResult::OnlyWithQuotes(what);
 	}
 	CommonStrCmdResult::None
 }
@@ -208,19 +198,18 @@ fn pos_tailhazard(horizon: &[u8], end: u8) -> (usize, usize) {
 }
 
 fn is_decimal(byte: u8) -> bool {
-	matches!(byte, b'0' ..= b'9')
+	byte.is_ascii_digit()
 }
 
 fn is_variable_of_numeric_content(c: u8) -> bool {
 	matches!(c, b'#' | b'?' | b'$' | b'!')
 }
 
-fn bail_doubledigit(context: &[u8], pos: usize) -> CommonStrCmdResult {
-	CommonStrCmdResult::Some(WhatNow{
-		tri: Transition::Err(UnsupportedSyntax{
+fn bail_doubledigit(pos: usize, len: usize) -> CommonStrCmdResult {
+	CommonStrCmdResult::Some(WhatNow {
+		transform: (pos, len, None),
+		transition: Transition::Err(UnsupportedSyntax {
 			typ: "Unsupported syntax: Syntactic pitfall",
-			ctx: context.to_owned(),
-			pos,
 			msg: "This does not mean what it looks like. You may be forgiven to think that the full string of \
 			numerals is the variable name. Only the fist is.\n\
 			\n\
@@ -235,6 +224,6 @@ fn bail_doubledigit(context: &[u8], pos: usize) -> CommonStrCmdResult {
 			* Fixing what it does would be 100% subtle \
 			and might slip through code review unnoticed.\n\
 			* Fixing its look would make a likely bug look intentional."
-		}), pre: 0, len: 0, alt: None
+		}),
 	})
 }
