@@ -10,9 +10,10 @@ use crate::situation::Situation;
 use crate::situation::WhatNow;
 use crate::situation::flush;
 use crate::situation::pop;
+use crate::situation::push;
 
 pub struct SitExtent{
-	pub len : usize,
+	pub len: usize,
 	pub color: u32,
 }
 
@@ -28,3 +29,11 @@ impl Situation for SitExtent {
 		self.color
 	}
 }
+
+pub fn push_extent(color: u32, pre: usize, len: usize) -> WhatNow {
+	push((pre, 0, None), Box::new(SitExtent { len, color }))
+}
+
+pub fn push_replaceable(color: u32, pre: usize, len: usize, alt: Option<&'static [u8]>) -> WhatNow {
+	push((pre, len, alt), Box::new(SitExtent { len: 0, color }))
+}
