@@ -7,14 +7,13 @@
  */
 
 use crate::situation::Situation;
-use crate::situation::Transition;
 use crate::situation::WhatNow;
 use crate::situation::flush;
 use crate::situation::pop;
 use crate::situation::COLOR_SQESC;
 use crate::situation::COLOR_ESC;
 
-use crate::sitextent::SitExtent;
+use crate::sitextent::push_extent;
 
 pub struct SitStrSqEsc {}
 
@@ -22,8 +21,7 @@ impl Situation for SitStrSqEsc {
 	fn whatnow(&mut self, horizon: &[u8], _is_horizon_lengthenable: bool) -> WhatNow {
 		for (i, &a) in horizon.iter().enumerate() {
 			if a == b'\\' {
-				let esc = Box::new(SitExtent{len: 1, color: COLOR_ESC});
-				return WhatNow{tri: Transition::Push(esc), pre: i, len: 1, alt: None};
+				return push_extent(COLOR_ESC, i, 2);
 			}
 			if a == b'\'' {
 				return pop(i, 1, None);
@@ -35,3 +33,14 @@ impl Situation for SitStrSqEsc {
 		COLOR_SQESC
 	}
 }
+
+#[cfg(test)]
+use crate::testhelpers::*;
+
+#[test]
+fn test_sit_strsqesc() {
+	sit_expect!(SitStrSqEsc{}, b"", &flush(0));
+	sit_expect!(SitStrSqEsc{}, b"$", &flush(1));
+	sit_expect!(SitStrSqEsc{}, b"\\", &push_extent(COLOR_ESC, 0, 2));
+	sit_expect!(SitStrSqEsc{}, b"\'", &pop(0, 1, None));
+}
